---
title: GitHub OAuth Setup
description: Detailed GitHub OAuth App setup guide.
---

import { Callout } from 'nextra/components'

<Callout type="info">
This page has moved. See [OAuth (GitHub)](../../built-in-apps/user-management/accounts/oauth) for the full documentation.
</Callout>
